% verfploeter_plotter
% ASM Rizvi <asmrizvi@usc.edu>
% October 14, 2019

# NAME

verfploeter_plotter - read pcap or fsdb files and generate anycast mapping.

# DESCRIPTION
	This tool generates anycast mapping from Verfploeter (or anything similar) outputs.
	This tool takes pcap or tab-delimeted (fsdb) text files as input.
	Each anycast site should have a pcap or fsdb file.
	The default base directory is current working directory, ".".
	Specify input directory or the tool will assume /BASE/Input/ directory for the input files.
	Input files should be in YYYY-MM-DD-SITE.pcap or YYYY-MM-DD-SITE.fsdb format, e.g. 2019-06-07-LAX.pcap or 2019-06-07-LAX.fsdb.
	Specify the output directory or the outputs will be generated in the /BASE/Output/ directory.
	This tool needs a file which includes all the target hitlists. Default is /BASE/ip_list.txt.
	It uses a geolocation database. A sample database is given at the base directory.
	The tool generates the mapping in png and pdf formats along with some other data files in /BASE/Output/ directory.
	Sample inputs are in /BASE/Input/ directory and sample outputs are in the /BASE/Output/ directory.

# SYNOPSIS

verfploeter_plotter [--year=*YYYY*] [--month=*MM*] [--day=*DD*] [--n=*NUMBER*] [--s=*SITE1,SITE2*]
			[--id=*ICMP_ID*] [--i=*INPUT*] [--o=*OUPUT*] [--database=*FILE*]
			[--scale=*NUMBER*] [--format=*pcap or fsdb*] [--targets=*FILE*]
			[--dir=*DIRECTORY*] [--help]

# DEPENDENCIES
- python3
- matplotlib (python3-basemap rpm)
- python-proj (python3-pyproj rpm)
- fsdb (perl-Fsdb rpm, for FSDB-input files, --format=fsdb)
- pingextract (for PCAP input files, --format=pcap)
  https://ant.isi.edu/software/verfploeter/pingextract/index.html

# INSTALLATION
- Install FSDB (perl-Fsdb rpm)
- Optionally Install pingextract. Copy the pingextract file in the script directory.
- Type "sudo make install"

# TESTING
- Type "sudo make test-pcap" to see the map from pcap files. Outputs will be in /BASE/Output/ directory
- Type "sudo make test-fsdb" to see the map from fsdb files. Outputs will be in /BASE/Output/ directory

# SUPPORTING FILES
- Target hitlist (sample: ip_list.txt). 
  The recent hitlist can be found here:
    https://ant.isi.edu/datasets/ip_hitlists/
 
- Internet address geolocation database (sample: geolocation.fsdb.bz2). 
  The geolocation database can be found here:
    https://ant.isi.edu/datasets/readmes/internet_outage_adaptive_a27_supplement-20170101.README.txt.

# FILE FORMAT
- pcap files. This script uses pingextract with an ICMP ID to get the relevant packets (sample files are provided with the package).
- fsdb file format: #fsdb block target site (sample files are provided with the package).
- IP hitlist: each line includes one target IP.
- Internet address geolocation database format (in fsdb.bz2 format): #fsdb -F t hexip ip latitude longitude country region city metro_code area_code color.

# EXAMPLES:
1. 3 sites (LAX,ARI,MIA) and pcap files are in /BASE/Input/ directory. ICMP packets have identifier 15000.
	verfploeter_plotter --year=2019 --month=07 --day=07 --n=3 --s=LAX,ARI,MIA --id=15000
	The outputs will be generated in /BASE/Output/ directory.
2. 2 sites (LAX,ARI) and fsdb formatted files are in /temp/input/ directory.
	verfploeter_plotter --year=2019 --month=09 --day=08 --n=2 --s=LAX,ARI --input=/tmp/input/ --format=fsdb
    The outputs will be generated in the /BASE/Output directory.
3. If you want to change the output directory:
    verfploeter_plotter --year=2019 --month=09 --day=08 --n=2 --s=LAX,ARI --input=/tmp/input/ --o=/tmp/output/ --format=fsdb
    Now, the outputs will be generated in /tmp/output/ directory.
4. If you want to change the base directory:
    verfploeter_plotter --year=2019 --month=09 --day=08 --n=2 --s=LAX,ARI --dir=/tmp/base/ --format=fsdb
    This will use /tmp/base/ as the base directory. The code will assume all the files are in /tmp/base/directory.
    This will override the given (if any) directory for target hitlist and geolocation database.

# OPTIONS
``--year``=*YYYY*
:Year of the pcap files
``--month``=*MM*
:Month of the pcap files
``--day``=*DD*
:Date of the pcap files
``--n``=*NUMBER*
:No. of anycast sites
``--s``=*SITE1,SITE2*
:List of the anycast sites separated by comma
``--format``=*pcap or fsdb*
:Format of the input files, default is pcap
``--database``=*FILE*
: Database file, default is geolocation.fsdb.bz2
``--dir``=*FILE*
: Base directory, default is /usr/share/doc/verfploetter_plotter
``--id``=*ICMP_ID*
:ID of the ICMP replies
`--i`=*FILE*
:Input directory, default is Input
`--o`=*FILE*
:Output directory, default is Output
``--scale``=*NUMBER*
:Scale of the mapping, default is 1500
`--targets`=*FILE*
:Target hitlist, default is ip_list.txt
`--help`	
:Prints help information

# CHANGES
* 0.1, 2019-10-15: initial release
